@@ -9,7 +9,11 @@ Getopt::Chain - svn- and git-style option and subcommand processing
 
 =head1 VERSION
 
-Version 0.001_1
+Version 0.001_2
+
+=cut
+
+our $VERSION = '0.001_2';
 
 =head1 SYNPOSIS 
 
@@ -85,8 +89,6 @@ So, for now, try to use distinct option names/aliases :)
 
 =cut
 
-our $VERSION = '0.001_1';
-
 use Moose;
 use Getopt::Chain::Carp;
 
@@ -268,6 +270,14 @@ L<MooseX::App::Cmd>
 
 Robert Krimen, C<< <rkrimen at cpan.org> >>
 
+=head1 SOURCE
+
+You can contribute or fork this project via GitHub:
+
+L<http://github.com/robertkrimen/getopt-chain/tree/master>
+
+    git clone git://github.com/robertkrimen/getopt-chain.git Getopt-Chain
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-getopt-chain at rt.cpan.org>, or through
